import React, { useState, useEffect, useMemo } from 'react'
import { Input } from 'antd'
import Icon, { EllipsisOutlined } from '@ant-design/icons'
import * as icons from '@ant-design/icons'

const iconList = Object.keys(icons).filter((item) => typeof icons[item] === 'object')

const TextInput = (props) => {

  const userInfo = window?.globalConfig?.userInfo || { fullName: '【本人姓名】', depart: { name: '【本人部门】' } }

  const { value, onChange, schema } = props
  const { disabled, placeholder, presetValue, prefix, suffix, maxLength, rules } = schema

  const valueShow = useMemo(() => {
    return value || presetValue
  }, [value, presetValue])

  const style = useMemo(() => {
    let paths = ['【本人姓名】', '【本人部门】']
    if (paths.includes(presetValue)) {
      if (presetValue === '【本人姓名】') {
        onChange(userInfo.fullName)
      } else if (presetValue === '【本人部门】') {
        onChange(userInfo.depart.name)
      }
      return { color: 'blue' }
    }
    return null
  }, [presetValue])

  const handleChange = (e) => {
    onChange(e.target.value)
  }

  return (
    <Input
      style={style}
      rules={rules}
      disabled={disabled}
      value={valueShow}
      maxLength={maxLength}
      placeholder={disabled ? null : placeholder}
      onChange={handleChange}
      addonBefore={iconList.includes(prefix) ? <Icon component={icons[prefix]} /> : prefix}
      addonAfter={iconList.includes(suffix) ? <Icon component={icons[suffix]} /> : suffix}
    />
  )

}

export default TextInput
